js.cookieconsent
****************

Introduction
============

This library packages `insites/cookieconsent`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`insites/cookieconsent`: https://github.com/insites/cookieconsent

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js/cookieconsent``) are published to some URL.
